@@ -8,14 +8,12 @@ package Getopt::Alt::Exception;
 
 use Moose;
 use version;
-use overload '""' => sub { shift->message };
+use overload '""' => sub { shift->as_string };
 
-our $VERSION = version->new('0.3.4');
+extends 'Throwable::Error';
+
+our $VERSION = version->new('0.3.5');
 
-has message => (
-    is      => 'rw',
-    isa     => 'Str',
-);
 has help => (
     is  => 'rw',
     isa => 'Bool',
@@ -39,7 +37,7 @@ Getopt::Alt::Exception - I have forgotten where I was going with this
 
 =head1 VERSION
 
-This documentation refers to Getopt::Alt::Exception version 0.3.4.
+This documentation refers to Getopt::Alt::Exception version 0.3.5.
 
 
 =head1 SYNOPSIS
